
import { useAjax } from '@/Hook/useAjax'
import {  Row,  message } from 'antd'
import React, { useEffect, useState, useCallback } from 'react'
import TableData from '../../components/TableData'
import tableConfig from './tableConfig'
import { putAdqAdAccountSyncByIds, getAdqAdAccountList } from '@/services/launchAdq/adq'
type Props = {
    accountId: string,
    adAccountId: string,
    userId: string,
    queryParmas: {
        accountId?: string,//账户ID
        campaignId?: string,//计划ID
        adgroupId?: string,//广告ID
        adcreativeId?: string,//创意ID
        pageId?: string,//落地页ID
        targetingId?: string,//定向ID}
    },
    tableIdClick: (props: {
        activeKey: string, parma: {
            accountId?: string,//账户ID
            campaignId?: string,//计划ID
            adgroupId?: string,//广告ID
            adcreativeId?: string,//创意ID
            pageId?: string,//落地页ID
            targetingId?: string,//定向ID
        }
    }) => void
}
function AdAccount(props:Props) {
    let { accountId, adAccountId, userId,tableIdClick } = props
    let [selectedRowKeys,setSelectedRowKeys]=useState<any[]>([])
    // api方法
    const listAjax = useAjax((params) => getAdqAdAccountList(params), { formatResult: true })
    const syncAjax = useAjax((params) => putAdqAdAccountSyncByIds(params))
    console.log('创意=====》')
    useEffect(() => {
        getList({ pageNum: 1, pageSize: 20 })
    }, [accountId, userId])
    // 获取列表
    const getList = useCallback((params: {
        pageNum: number;
        pageSize: number;
        accountId?: string;
        adcreativeName?: string;
    }) => {
        if (!params.adcreativeName || params.adcreativeName !== listAjax?.params[0]?.adcreativeName) {
            !params.adcreativeName && delete params.adcreativeName
            listAjax.run({ ...params, userId, accountIds:accountId?[accountId]:null })
        }
    }, [accountId, userId, listAjax])
    // 同步 
    const sync = useCallback(() => {
        if (selectedRowKeys?.length === 0) {
            message.error('请勾选要同步的广点通账号!')
            return
        }
        syncAjax.run(selectedRowKeys).then(res => {
            res && listAjax.refresh()
            res ? message.success('同步成功！') : message.error('同步失败！')

        })
    }, [adAccountId, listAjax,selectedRowKeys])
    return <div>
        <TableData
            columns={()=>tableConfig(tableIdClick)}
            ajax={listAjax}
            syncAjax={sync}
            dataSource={listAjax?.data?.data?.records}
            loading={listAjax?.loading || syncAjax?.loading}
            scroll={{ y:550 }}
            total={listAjax?.data?.data?.total}
            page={listAjax?.data?.data?.current}
            pageSize={listAjax?.data?.data?.size}
            leftChild={<>
                <Row gutter={[10, 10]}>
                </Row>
            </>}
            rowSelection={{
                onChange: (selectedRowKeys: React.Key[], selectedRows: any[]) => {
                    setSelectedRowKeys(selectedRowKeys)
                }
            }}
            onChange={(props: any) => {
                let { sortData, pagination } = props
                let { current, pageSize } = pagination
                getList({ pageNum: current, pageSize })
            }}
        />
    </div>
}
export default AdAccount